@@ -5,10 +5,11 @@ combine_rare_levels <- function(x,threshold=20,newname="Combined") {
   
   levels(x)[ which(levels(x) %in% rare.levels) ] <- newname
   ST <- sort(table(x))
-  if(ST["Combined"]<=threshold) {  #Combined will be the least frequent level
+  if(ST[newname]<=threshold) {  #Combined will be the least frequent level
     levels.to.combine <- which( levels(x) %in% c(newname,names(ST)[2]))
     levels(x)[levels.to.combine] <- newname
     rare.levels <- c(rare.levels,names(ST)[2])}
+  x <- factor(as.character(x))
   return(list(values=x,combined=rare.levels))
 }
 
