@@ -1,5 +1,15 @@
 confusion_matrix <-
 function(M,DATA=NA) {
+
+  is.caret.glm <- ( head(class(M),1)=="train" & (if(length(M$method>0)){M$method=="glm"}else{FALSE})  )
+  if(is.caret.glm) {
+    NEW <- M$trainingData
+    form <- as.character(formula(M))
+    names(NEW)[1] <- form[2]
+    form <- as.formula(paste(form[2],form[1],form[-(1:2)]))
+    M <- glm(form,data=NEW,family=binomial) 
+  }
+  
     if(missing(DATA)) { DATA <- M$model }
     D <- names(DATA)
     y.label <- as.character(M$terms[[2]])
