@@ -1,6 +1,8 @@
 qq <-
 function(x,ax=NA,leg=NA,cex.leg=0.8)  {
-  if (! ( head(class(x),1) %in% c("integer","numeric") ) ) { stop(paste("Error:  only allows numeric variables.  You passed a",class(x))) }
+  if (!inherits(x, c("numeric", "integer"))) {
+    stop(paste("Error: only allows numeric variables. You passed a", class(x)))
+  }
   if(is.na(ax)) { x.label <- deparse(substitute(x)) } else { x.label <- ax }
   x <- sort(x)
   n <- length(x)
